diff --git a/htdocs/admin/modules.php b/htdocs/admin/modules.php
index 89f0f028e1e..538fb86ce2e 100644
--- a/htdocs/admin/modules.php
+++ b/htdocs/admin/modules.php
@@ -1063,7 +1063,7 @@ if ($mode == 'develop')
//print '
';
print '
';
print '';
- print ''.$langs->trans("TryToUseTheModuleBuilder").' | ';
+ print ''.$langs->trans("TryToUseTheModuleBuilder", $langs->transnoentitiesnoconv("ModuleBuilder")).' | ';
print ''.$langs->trans("SeeTopRightMenu").' | ';
print '';
diff --git a/htdocs/admin/system/filecheck.php b/htdocs/admin/system/filecheck.php
index 0418830cce8..10cffafb9a9 100644
--- a/htdocs/admin/system/filecheck.php
+++ b/htdocs/admin/system/filecheck.php
@@ -337,7 +337,13 @@ if (! $error && $xml)
$i++;
$out.='';
$out.='| '.$i.' | ' . "\n";
- $out.=''.$file['filename'].' | ' . "\n";
+ $out.=''.$file['filename'];
+ $out.=PHP_OS;
+ if (! preg_match('/^win/i',PHP_OS)) {
+ $htmltext=$langs->trans("YouCanDeleteFileOnServerWith", 'rm '.DOL_DOCUMENT_ROOT.'/'.$file['filename']);
+ $out.=' '.$form->textwithpicto('', $htmltext, 1, 'help', '', 0, 2, 'helprm');
+ }
+ $out.=' | ' . "\n";
$out.=''.$file['expectedmd5'].' | ' . "\n";
$out.=''.$file['md5'].' | ' . "\n";
$size = dol_filesize(DOL_DOCUMENT_ROOT.'/'.$file['filename']);
diff --git a/htdocs/comm/action/class/actioncomm.class.php b/htdocs/comm/action/class/actioncomm.class.php
index 7b9caabb8a9..c175ad900ea 100644
--- a/htdocs/comm/action/class/actioncomm.class.php
+++ b/htdocs/comm/action/class/actioncomm.class.php
@@ -1166,58 +1166,58 @@ class ActionComm extends CommonObject
if ($mode == 0)
{
if ($percent==-1 && ! $hidenastatus) return $langs->trans('StatusNotApplicable');
- else if ($percent==0) return $langs->trans('StatusActionToDo').' (0%)';
- else if ($percent > 0 && $percent < 100) return $langs->trans('StatusActionInProcess').' ('.$percent.'%)';
- else if ($percent >= 100) return $langs->trans('StatusActionDone').' (100%)';
+ elseif ($percent==0) return $langs->trans('StatusActionToDo').' (0%)';
+ elseif ($percent > 0 && $percent < 100) return $langs->trans('StatusActionInProcess').' ('.$percent.'%)';
+ elseif ($percent >= 100) return $langs->trans('StatusActionDone').' (100%)';
}
- else if ($mode == 1)
+ elseif ($mode == 1)
{
if ($percent==-1 && ! $hidenastatus) return $langs->trans('StatusNotApplicable');
- else if ($percent==0) return $langs->trans('StatusActionToDo');
- else if ($percent > 0 && $percent < 100) return $percent.'%';
- else if ($percent >= 100) return $langs->trans('StatusActionDone');
+ elseif ($percent==0) return $langs->trans('StatusActionToDo');
+ elseif ($percent > 0 && $percent < 100) return $percent.'%';
+ elseif ($percent >= 100) return $langs->trans('StatusActionDone');
}
- else if ($mode == 2)
+ elseif ($mode == 2)
{
if ($percent==-1 && ! $hidenastatus) return img_picto($langs->trans('StatusNotApplicable'),'statut9').' '.$langs->trans('StatusNotApplicable');
- else if ($percent==0) return img_picto($langs->trans('StatusActionToDo'),'statut1').' '.$langs->trans('StatusActionToDo');
- else if ($percent > 0 && $percent < 100) return img_picto($langs->trans('StatusActionInProcess'),'statut3').' '. $percent.'%';
- else if ($percent >= 100) return img_picto($langs->trans('StatusActionDone'),'statut6').' '.$langs->trans('StatusActionDone');
+ elseif ($percent==0) return img_picto($langs->trans('StatusActionToDo'),'statut1').' '.$langs->trans('StatusActionToDo');
+ elseif ($percent > 0 && $percent < 100) return img_picto($langs->trans('StatusActionInProcess'),'statut3').' '. $percent.'%';
+ elseif ($percent >= 100) return img_picto($langs->trans('StatusActionDone'),'statut6').' '.$langs->trans('StatusActionDone');
}
- else if ($mode == 3)
+ elseif ($mode == 3)
{
if ($percent==-1 && ! $hidenastatus) return img_picto($langs->trans("Status").': '.$langs->trans('StatusNotApplicable'),'statut9');
- else if ($percent==0) return img_picto($langs->trans("Status").': '.$langs->trans('StatusActionToDo').' (0%)','statut1');
- else if ($percent > 0 && $percent < 100) return img_picto($langs->trans("Status").': '.$langs->trans('StatusActionInProcess').' ('.$percent.'%)','statut3');
- else if ($percent >= 100) return img_picto($langs->trans("Status").': '.$langs->trans('StatusActionDone').' (100%)','statut6');
+ elseif ($percent==0) return img_picto($langs->trans("Status").': '.$langs->trans('StatusActionToDo').' (0%)','statut1');
+ elseif ($percent > 0 && $percent < 100) return img_picto($langs->trans("Status").': '.$langs->trans('StatusActionInProcess').' ('.$percent.'%)','statut3');
+ elseif ($percent >= 100) return img_picto($langs->trans("Status").': '.$langs->trans('StatusActionDone').' (100%)','statut6');
}
- else if ($mode == 4)
+ elseif ($mode == 4)
{
if ($percent==-1 && ! $hidenastatus) return img_picto($langs->trans('StatusNotApplicable'),'statut9').' '.$langs->trans('StatusNotApplicable');
- else if ($percent==0) return img_picto($langs->trans('StatusActionToDo'),'statut1').' '.$langs->trans('StatusActionToDo').' (0%)';
- else if ($percent > 0 && $percent < 100) return img_picto($langs->trans('StatusActionInProcess'),'statut3').' '.$langs->trans('StatusActionInProcess').' ('.$percent.'%)';
- else if ($percent >= 100) return img_picto($langs->trans('StatusActionDone'),'statut6').' '.$langs->trans('StatusActionDone').' (100%)';
+ elseif ($percent==0) return img_picto($langs->trans('StatusActionToDo'),'statut1').' '.$langs->trans('StatusActionToDo').' (0%)';
+ elseif ($percent > 0 && $percent < 100) return img_picto($langs->trans('StatusActionInProcess'),'statut3').' '.$langs->trans('StatusActionInProcess').' ('.$percent.'%)';
+ elseif ($percent >= 100) return img_picto($langs->trans('StatusActionDone'),'statut6').' '.$langs->trans('StatusActionDone').' (100%)';
}
- else if ($mode == 5)
+ elseif ($mode == 5)
{
if ($percent==-1 && ! $hidenastatus) return img_picto($langs->trans('StatusNotApplicable'),'statut9');
- else if ($percent==0) return '0% '.img_picto($langs->trans('StatusActionToDo'),'statut1');
- else if ($percent > 0 && $percent < 100) return $percent.'% '.img_picto($langs->trans('StatusActionInProcess').' - '.$percent.'%','statut3');
- else if ($percent >= 100) return $langs->trans('StatusActionDone').' '.img_picto($langs->trans('StatusActionDone'),'statut6');
+ elseif ($percent==0) return '0% '.img_picto($langs->trans('StatusActionToDo'),'statut1');
+ elseif ($percent > 0 && $percent < 100) return $percent.'% '.img_picto($langs->trans('StatusActionInProcess').' - '.$percent.'%','statut3');
+ elseif ($percent >= 100) return $langs->trans('StatusActionDone').' '.img_picto($langs->trans('StatusActionDone'),'statut6');
}
- else if ($mode == 6)
+ elseif ($mode == 6)
{
if ($percent==-1 && ! $hidenastatus) return $langs->trans('StatusNotApplicable').' '.img_picto($langs->trans('StatusNotApplicable'),'statut9');
- else if ($percent==0) return $langs->trans('StatusActionToDo').' (0%) '.img_picto($langs->trans('StatusActionToDo'),'statut1');
- else if ($percent > 0 && $percent < 100) return $langs->trans('StatusActionInProcess').' ('.$percent.'%) '.img_picto($langs->trans('StatusActionInProcess').' - '.$percent.'%','statut3');
- else if ($percent >= 100) return $langs->trans('StatusActionDone').' (100%) '.img_picto($langs->trans('StatusActionDone'),'statut6');
+ elseif ($percent==0) return $langs->trans('StatusActionToDo').' (0%) '.img_picto($langs->trans('StatusActionToDo'),'statut1');
+ elseif ($percent > 0 && $percent < 100) return $langs->trans('StatusActionInProcess').' ('.$percent.'%) '.img_picto($langs->trans('StatusActionInProcess').' - '.$percent.'%','statut3');
+ elseif ($percent >= 100) return $langs->trans('StatusActionDone').' (100%) '.img_picto($langs->trans('StatusActionDone'),'statut6');
}
- else if ($mode == 7)
+ elseif ($mode == 7)
{
if ($percent==-1 && ! $hidenastatus) return img_picto($langs->trans('StatusNotApplicable'),'statut9');
- else if ($percent==0) return '0% '.img_picto($langs->trans('StatusActionToDo'),'statut1');
- else if ($percent > 0 && $percent < 100) return $percent.'% '.img_picto($langs->trans('StatusActionInProcess').' - '.$percent.'%','statut3');
- else if ($percent >= 100) return img_picto($langs->trans('StatusActionDone'),'statut6');
+ elseif ($percent==0) return '0% '.img_picto($langs->trans('StatusActionToDo'),'statut1');
+ elseif ($percent > 0 && $percent < 100) return $percent.'% '.img_picto($langs->trans('StatusActionInProcess').' - '.$percent.'%','statut3');
+ elseif ($percent >= 100) return img_picto($langs->trans('StatusActionDone'),'statut6');
}
return '';
@@ -1564,8 +1564,8 @@ class ActionComm extends CommonObject
// Write file
if ($format == 'vcal') $result=build_calfile($format,$title,$desc,$eventarray,$outputfiletmp);
- if ($format == 'ical') $result=build_calfile($format,$title,$desc,$eventarray,$outputfiletmp);
- if ($format == 'rss') $result=build_rssfile($format,$title,$desc,$eventarray,$outputfiletmp);
+ elseif ($format == 'ical') $result=build_calfile($format,$title,$desc,$eventarray,$outputfiletmp);
+ elseif ($format == 'rss') $result=build_rssfile($format,$title,$desc,$eventarray,$outputfiletmp);
if ($result >= 0)
{
diff --git a/htdocs/comm/action/class/actioncommreminder.class.php b/htdocs/comm/action/class/actioncommreminder.class.php
index 63773661cbd..6c9632d83e5 100644
--- a/htdocs/comm/action/class/actioncommreminder.class.php
+++ b/htdocs/comm/action/class/actioncommreminder.class.php
@@ -189,32 +189,32 @@ class ActionCommReminder extends CommonObject
if ($mode == 0 || $mode == 1)
{
if ($status == 1) return $langs->trans('Done');
- if ($status == 0) return $langs->trans('ToDo');
+ elseif ($status == 0) return $langs->trans('ToDo');
}
elseif ($mode == 2)
{
if ($status == 1) return img_picto($langs->trans('Done'),'statut4').' '.$langs->trans('Done');
- if ($status == 0) return img_picto($langs->trans('ToDo'),'statut5').' '.$langs->trans('ToDo');
+ elseif ($status == 0) return img_picto($langs->trans('ToDo'),'statut5').' '.$langs->trans('ToDo');
}
elseif ($mode == 3)
{
if ($status == 1) return img_picto($langs->trans('Done'),'statut4');
- if ($status == 0) return img_picto($langs->trans('ToDo'),'statut5');
+ elseif ($status == 0) return img_picto($langs->trans('ToDo'),'statut5');
}
elseif ($mode == 4)
{
if ($status == 1) return img_picto($langs->trans('Done'),'statut4').' '.$langs->trans('Done');
- if ($status == 0) return img_picto($langs->trans('ToDo'),'statut5').' '.$langs->trans('ToDo');
+ elseif ($status == 0) return img_picto($langs->trans('ToDo'),'statut5').' '.$langs->trans('ToDo');
}
elseif ($mode == 5)
{
if ($status == 1) return $langs->trans('Done').' '.img_picto($langs->trans('Done'),'statut4');
- if ($status == 0) return $langs->trans('ToDo').' '.img_picto($langs->trans('ToDo'),'statut5');
+ elseif ($status == 0) return $langs->trans('ToDo').' '.img_picto($langs->trans('ToDo'),'statut5');
}
elseif ($mode == 6)
{
if ($status == 1) return $langs->trans('Done').' '.img_picto($langs->trans('Done'),'statut4');
- if ($status == 0) return $langs->trans('ToDo').' '.img_picto($langs->trans('ToDo'),'statut5');
+ elseif ($status == 0) return $langs->trans('ToDo').' '.img_picto($langs->trans('ToDo'),'statut5');
}
}
diff --git a/htdocs/compta/facture/class/paymentterm.class.php b/htdocs/compta/facture/class/paymentterm.class.php
index 619487e9574..31e362445f0 100644
--- a/htdocs/compta/facture/class/paymentterm.class.php
+++ b/htdocs/compta/facture/class/paymentterm.class.php
@@ -135,18 +135,17 @@ class PaymentTerm // extends CommonObject
{
$this->id = $this->db->last_insert_id(MAIN_DB_PREFIX."c_payment_term");
- if (! $notrigger)
- {
- // Uncomment this and change MYOBJECT to your own tag if you
- // want this action call a trigger.
+ // Uncomment this and change MYOBJECT to your own tag if you
+ // want this action call a trigger.
+ //if (! $notrigger) {
- //// Call triggers
- //include_once DOL_DOCUMENT_ROOT . '/core/class/interfaces.class.php';
- //$interface=new Interfaces($this->db);
- //$result=$interface->run_triggers('MYOBJECT_CREATE',$this,$user,$langs,$conf);
- //if ($result < 0) { $error++; $this->errors=$interface->errors; }
- //// End call triggers
- }
+ // // Call triggers
+ // include_once DOL_DOCUMENT_ROOT . '/core/class/interfaces.class.php';
+ // $interface=new Interfaces($this->db);
+ // $result=$interface->run_triggers('MYOBJECT_CREATE',$this,$user,$langs,$conf);
+ // if ($result < 0) { $error++; $this->errors=$interface->errors; }
+ // // End call triggers
+ //}
}
// Commit or rollback
@@ -311,21 +310,16 @@ class PaymentTerm // extends CommonObject
$resql = $this->db->query($sql);
if (! $resql) { $error++; $this->errors[]="Error ".$this->db->lasterror(); }
- if (! $error)
- {
- if (! $notrigger)
- {
- // Uncomment this and change MYOBJECT to your own tag if you
- // want this action call a trigger.
-
+ // Uncomment this and change MYOBJECT to your own tag if you
+ // want this action call a trigger.
+ //if (! $error && ! $notrigger) {
// Call triggers
//include_once DOL_DOCUMENT_ROOT . '/core/class/interfaces.class.php';
//$interface=new Interfaces($this->db);
//$result=$interface->run_triggers('MYOBJECT_MODIFY',$this,$user,$langs,$conf);
//if ($result < 0) { $error++; $this->errors=$interface->errors; }
// End call triggers
- }
- }
+ //}
// Commit or rollback
if ($error)
@@ -367,21 +361,16 @@ class PaymentTerm // extends CommonObject
$resql = $this->db->query($sql);
if (! $resql) { $error++; $this->errors[]="Error ".$this->db->lasterror(); }
- if (! $error)
- {
- if (! $notrigger)
- {
- // Uncomment this and change MYOBJECT to your own tag if you
- // want this action call a trigger.
-
+ // Uncomment this and change MYOBJECT to your own tag if you
+ // want this action call a trigger.
+ //if (! $error && ! $notrigger) {
//// Call triggers
//include_once DOL_DOCUMENT_ROOT . '/core/class/interfaces.class.php';
//$interface=new Interfaces($this->db);
//$result=$interface->run_triggers('MYOBJECT_DELETE',$this,$user,$langs,$conf);
//if ($result < 0) { $error++; $this->errors=$interface->errors; }
//// End call triggers
- }
- }
+ //}
// Commit or rollback
if ($error)
@@ -439,12 +428,9 @@ class PaymentTerm // extends CommonObject
$error++;
}
- if (! $error)
- {
-
-
-
- }
+ //if (! $error)
+ //{
+ //}
unset($this->context['createfromclone']);
diff --git a/htdocs/compta/sociales/class/cchargesociales.class.php b/htdocs/compta/sociales/class/cchargesociales.class.php
index 409ee99aaae..dc2bbc5c9da 100644
--- a/htdocs/compta/sociales/class/cchargesociales.class.php
+++ b/htdocs/compta/sociales/class/cchargesociales.class.php
@@ -77,31 +77,18 @@ class Cchargesociales
$error = 0;
- // Clean parameters
-
- if (isset($this->libelle)) {
- $this->libelle = trim($this->libelle);
- }
- if (isset($this->deductible)) {
- $this->deductible = trim($this->deductible);
- }
- if (isset($this->active)) {
- $this->active = trim($this->active);
- }
- if (isset($this->code)) {
- $this->code = trim($this->code);
- }
- if (isset($this->fk_pays)) {
- $this->fk_pays = trim($this->fk_pays);
- }
- if (isset($this->module)) {
- $this->module = trim($this->module);
- }
- if (isset($this->accountancy_code)) {
- $this->accountancy_code = trim($this->accountancy_code);
- }
-
-
+ // Clean parameters
+ $this->trimParameters(
+ array(
+ 'libelle',
+ 'deductible',
+ 'active',
+ 'code',
+ 'fk_pays',
+ 'module',
+ 'accountancy_code',
+ )
+ );
// Check parameters
// Put here code to add control on parameters values
@@ -143,7 +130,7 @@ class Cchargesociales
if (!$error) {
$this->id = $this->db->last_insert_id(MAIN_DB_PREFIX . $this->table_element);
- if (!$notrigger) {
+ //if (!$notrigger) {
// Uncomment this and change MYOBJECT to your own tag if you
// want this action to call a trigger.
@@ -151,7 +138,7 @@ class Cchargesociales
//$result=$this->call_trigger('MYOBJECT_CREATE',$user);
//if ($result < 0) $error++;
//// End call triggers
- }
+ //}
}
// Commit or rollback
@@ -243,28 +230,17 @@ class Cchargesociales
// Clean parameters
- if (isset($this->libelle)) {
- $this->libelle = trim($this->libelle);
- }
- if (isset($this->deductible)) {
- $this->deductible = trim($this->deductible);
- }
- if (isset($this->active)) {
- $this->active = trim($this->active);
- }
- if (isset($this->code)) {
- $this->code = trim($this->code);
- }
- if (isset($this->fk_pays)) {
- $this->fk_pays = trim($this->fk_pays);
- }
- if (isset($this->module)) {
- $this->module = trim($this->module);
- }
- if (isset($this->accountancy_code)) {
- $this->accountancy_code = trim($this->accountancy_code);
- }
-
+ $this->trimParameters(
+ array(
+ 'libelle',
+ 'deductible',
+ 'active',
+ 'code',
+ 'fk_pays',
+ 'module',
+ 'accountancy_code',
+ )
+ );
// Check parameters
@@ -290,7 +266,7 @@ class Cchargesociales
dol_syslog(__METHOD__ . ' ' . join(',', $this->errors), LOG_ERR);
}
- if (!$error && !$notrigger) {
+ //if (!$error && !$notrigger) {
// Uncomment this and change MYOBJECT to your own tag if you
// want this action calls a trigger.
@@ -298,7 +274,7 @@ class Cchargesociales
//$result=$this->call_trigger('MYOBJECT_MODIFY',$user);
//if ($result < 0) { $error++; //Do also what you must do to rollback action if trigger fail}
//// End call triggers
- }
+ //}
// Commit or rollback
if ($error) {
@@ -328,8 +304,8 @@ class Cchargesociales
$this->db->begin();
- if (!$error) {
- if (!$notrigger) {
+ //if (!$error) {
+ //if (!$notrigger) {
// Uncomment this and change MYOBJECT to your own tag if you
// want this action calls a trigger.
@@ -337,8 +313,8 @@ class Cchargesociales
//$result=$this->call_trigger('MYOBJECT_DELETE',$user);
//if ($result < 0) { $error++; //Do also what you must do to rollback action if trigger fail}
//// End call triggers
- }
- }
+ //}
+ //}
if (!$error) {
$sql = 'DELETE FROM ' . MAIN_DB_PREFIX . $this->table_element;
@@ -476,34 +452,33 @@ class Cchargesociales
if ($mode == 0)
{
- $prefix='';
if ($status == 1) return $langs->trans('Enabled');
- if ($status == 0) return $langs->trans('Disabled');
+ elseif ($status == 0) return $langs->trans('Disabled');
}
- if ($mode == 1)
+ elseif ($mode == 1)
{
if ($status == 1) return $langs->trans('Enabled');
- if ($status == 0) return $langs->trans('Disabled');
+ elseif ($status == 0) return $langs->trans('Disabled');
}
- if ($mode == 2)
+ elseif ($mode == 2)
{
if ($status == 1) return img_picto($langs->trans('Enabled'),'statut4').' '.$langs->trans('Enabled');
- if ($status == 0) return img_picto($langs->trans('Disabled'),'statut5').' '.$langs->trans('Disabled');
+ elseif ($status == 0) return img_picto($langs->trans('Disabled'),'statut5').' '.$langs->trans('Disabled');
}
- if ($mode == 3)
+ elseif ($mode == 3)
{
if ($status == 1) return img_picto($langs->trans('Enabled'),'statut4');
- if ($status == 0) return img_picto($langs->trans('Disabled'),'statut5');
+ elseif ($status == 0) return img_picto($langs->trans('Disabled'),'statut5');
}
- if ($mode == 4)
+ elseif ($mode == 4)
{
if ($status == 1) return img_picto($langs->trans('Enabled'),'statut4').' '.$langs->trans('Enabled');
- if ($status == 0) return img_picto($langs->trans('Disabled'),'statut5').' '.$langs->trans('Disabled');
+ elseif ($status == 0) return img_picto($langs->trans('Disabled'),'statut5').' '.$langs->trans('Disabled');
}
- if ($mode == 5)
+ elseif ($mode == 5)
{
if ($status == 1) return $langs->trans('Enabled').' '.img_picto($langs->trans('Enabled'),'statut4');
- if ($status == 0) return $langs->trans('Disabled').' '.img_picto($langs->trans('Disabled'),'statut5');
+ elseif ($status == 0) return $langs->trans('Disabled').' '.img_picto($langs->trans('Disabled'),'statut5');
}
}
diff --git a/htdocs/compta/sociales/class/chargesociales.class.php b/htdocs/compta/sociales/class/chargesociales.class.php
index 3067242ae16..aa5786d0eb5 100644
--- a/htdocs/compta/sociales/class/chargesociales.class.php
+++ b/htdocs/compta/sociales/class/chargesociales.class.php
@@ -430,8 +430,9 @@ class ChargeSociales extends CommonObject
{
// phpcs:enable
global $langs;
- $langs->load('customers');
- $langs->load('bills');
+
+ // Load translation files required by the page
+ $langs->loadLangs(array("customers","bills"));
if ($mode == 0 || $mode == 1)
{
diff --git a/htdocs/contact/class/contact.class.php b/htdocs/contact/class/contact.class.php
index f81c4eed4c3..e5fc015da93 100644
--- a/htdocs/contact/class/contact.class.php
+++ b/htdocs/contact/class/contact.class.php
@@ -100,7 +100,7 @@ class Contact extends CommonObject
public $state_code; // Code of department
public $state; // Label of department
- public $poste; // Position
+ public $poste; // Position
public $socid; // fk_soc
public $statut; // 0=inactif, 1=actif
@@ -493,8 +493,8 @@ class Contact extends CommonObject
global $conf;
$dn='';
if ($mode==0) $dn=$conf->global->LDAP_KEY_CONTACTS."=".$info[$conf->global->LDAP_KEY_CONTACTS].",".$conf->global->LDAP_CONTACT_DN;
- if ($mode==1) $dn=$conf->global->LDAP_CONTACT_DN;
- if ($mode==2) $dn=$conf->global->LDAP_KEY_CONTACTS."=".$info[$conf->global->LDAP_KEY_CONTACTS];
+ elseif ($mode==1) $dn=$conf->global->LDAP_CONTACT_DN;
+ elseif ($mode==2) $dn=$conf->global->LDAP_KEY_CONTACTS."=".$info[$conf->global->LDAP_KEY_CONTACTS];
return $dn;
}
@@ -508,12 +508,12 @@ class Contact extends CommonObject
function _load_ldap_info()
{
// phpcs:enable
- global $conf,$langs;
+ global $conf, $langs;
$info = array();
// Object classes
- $info["objectclass"]=explode(',',$conf->global->LDAP_CONTACT_OBJECT_CLASS);
+ $info["objectclass"]=explode(',', $conf->global->LDAP_CONTACT_OBJECT_CLASS);
$this->fullname=$this->getFullName($langs);
@@ -887,9 +887,9 @@ class Contact extends CommonObject
if ($obj->nb)
{
if ($obj->element=='facture') $this->ref_facturation = $obj->nb;
- if ($obj->element=='contrat') $this->ref_contrat = $obj->nb;
- if ($obj->element=='commande') $this->ref_commande = $obj->nb;
- if ($obj->element=='propal') $this->ref_propal = $obj->nb;
+ elseif ($obj->element=='contrat') $this->ref_contrat = $obj->nb;
+ elseif ($obj->element=='commande') $this->ref_commande = $obj->nb;
+ elseif ($obj->element=='propal') $this->ref_propal = $obj->nb;
}
}
$this->db->free($resql);
@@ -914,8 +914,8 @@ class Contact extends CommonObject
$error=0;
- $this->old_lastname = $obj->lastname;
- $this->old_firstname = $obj->firstname;
+ $this->old_lastname = $obj->lastname;
+ $this->old_firstname = $obj->firstname;
$this->db->begin();
@@ -1035,7 +1035,7 @@ class Contact extends CommonObject
{
$obj = $this->db->fetch_object($resql);
- $this->id = $obj->rowid;
+ $this->id = $obj->rowid;
if ($obj->fk_user_creat) {
$cuser = new User($this->db);
diff --git a/htdocs/contrat/class/contrat.class.php b/htdocs/contrat/class/contrat.class.php
index d3e0c4de2c6..e76c7c34376 100644
--- a/htdocs/contrat/class/contrat.class.php
+++ b/htdocs/contrat/class/contrat.class.php
@@ -1845,28 +1845,28 @@ class Contrat extends CommonObject
if ($mode == 0)
{
if ($statut == 0) { return $langs->trans("ContractStatusDraft"); }
- if ($statut == 1) { return $langs->trans("ContractStatusValidated"); }
- if ($statut == 2) { return $langs->trans("ContractStatusClosed"); }
+ elseif ($statut == 1) { return $langs->trans("ContractStatusValidated"); }
+ elseif ($statut == 2) { return $langs->trans("ContractStatusClosed"); }
}
- if ($mode == 1)
+ elseif ($mode == 1)
{
if ($statut == 0) { return $langs->trans("ContractStatusDraft"); }
- if ($statut == 1) { return $langs->trans("ContractStatusValidated"); }
- if ($statut == 2) { return $langs->trans("ContractStatusClosed"); }
+ elseif ($statut == 1) { return $langs->trans("ContractStatusValidated"); }
+ elseif ($statut == 2) { return $langs->trans("ContractStatusClosed"); }
}
- if ($mode == 2)
+ elseif ($mode == 2)
{
if ($statut == 0) { return img_picto($langs->trans('ContractStatusDraft'),'statut0').' '.$langs->trans("ContractStatusDraft"); }
- if ($statut == 1) { return img_picto($langs->trans('ContractStatusValidated'),'statut4').' '.$langs->trans("ContractStatusValidated"); }
- if ($statut == 2) { return img_picto($langs->trans('ContractStatusClosed'),'statut6').' '.$langs->trans("ContractStatusClosed"); }
+ elseif ($statut == 1) { return img_picto($langs->trans('ContractStatusValidated'),'statut4').' '.$langs->trans("ContractStatusValidated"); }
+ elseif ($statut == 2) { return img_picto($langs->trans('ContractStatusClosed'),'statut6').' '.$langs->trans("ContractStatusClosed"); }
}
- if ($mode == 3)
+ elseif ($mode == 3)
{
if ($statut == 0) { return img_picto($langs->trans('ContractStatusDraft'),'statut0'); }
- if ($statut == 1) { return img_picto($langs->trans('ContractStatusValidated'),'statut4'); }
- if ($statut == 2) { return img_picto($langs->trans('ContractStatusClosed'),'statut6'); }
+ elseif ($statut == 1) { return img_picto($langs->trans('ContractStatusValidated'),'statut4'); }
+ elseif ($statut == 2) { return img_picto($langs->trans('ContractStatusClosed'),'statut6'); }
}
- if ($mode == 4 || $mode == 6 || $mode == 7)
+ elseif ($mode == 4 || $mode == 6 || $mode == 7)
{
$text='';
if ($mode == 4)
@@ -1888,11 +1888,11 @@ class Contrat extends CommonObject
$text.=($mode == 7?'':'');
return $text;
}
- if ($mode == 5)
+ elseif ($mode == 5)
{
if ($statut == 0) { return $langs->trans("ContractStatusDraft").' '.img_picto($langs->trans('ContractStatusDraft'),'statut0'); }
- if ($statut == 1) { return $langs->trans("ContractStatusValidated").' '.img_picto($langs->trans('ContractStatusValidated'),'statut4'); }
- if ($statut == 2) { return $langs->trans("ContractStatusClosed").' '.img_picto($langs->trans('ContractStatusClosed'),'statut6'); }
+ elseif ($statut == 1) { return $langs->trans("ContractStatusValidated").' '.img_picto($langs->trans('ContractStatusValidated'),'statut4'); }
+ elseif ($statut == 2) { return $langs->trans("ContractStatusClosed").' '.img_picto($langs->trans('ContractStatusClosed'),'statut6'); }
}
}
@@ -2116,7 +2116,7 @@ class Contrat extends CommonObject
$sql.= " AND c.rowid = cd.fk_contrat";
$sql.= " AND cd.statut = 0";
}
- if ($mode == 'expired')
+ elseif ($mode == 'expired')
{
$sql = "SELECT cd.rowid, cd.date_fin_validite as datefin";
$sql.= $this->from;
@@ -2637,50 +2637,50 @@ class ContratLigne extends CommonObjectLine
if ($mode == 0)
{
if ($statut == self::STATUS_INITIAL) { return $langs->trans("ServiceStatusInitial"); }
- if ($statut == self::STATUS_OPEN && $expired == -1) { return $langs->trans("ServiceStatusRunning"); }
- if ($statut == self::STATUS_OPEN && $expired == 0) { return $langs->trans("ServiceStatusNotLate"); }
- if ($statut == self::STATUS_OPEN && $expired == 1) { return $langs->trans("ServiceStatusLate"); }
- if ($statut == self::STATUS_CLOSED) { return $langs->trans("ServiceStatusClosed"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == -1) { return $langs->trans("ServiceStatusRunning"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 0) { return $langs->trans("ServiceStatusNotLate"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 1) { return $langs->trans("ServiceStatusLate"); }
+ elseif ($statut == self::STATUS_CLOSED) { return $langs->trans("ServiceStatusClosed"); }
}
- if ($mode == 1)
+ elseif ($mode == 1)
{
if ($statut == self::STATUS_INITIAL) { return $langs->trans("ServiceStatusInitial"); }
- if ($statut == self::STATUS_OPEN && $expired == -1) { return $langs->trans("ServiceStatusRunning"); }
- if ($statut == self::STATUS_OPEN && $expired == 0) { return $langs->trans("ServiceStatusNotLateShort"); }
- if ($statut == self::STATUS_OPEN && $expired == 1) { return $langs->trans("ServiceStatusLateShort"); }
- if ($statut == self::STATUS_CLOSED) { return $langs->trans("ServiceStatusClosed"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == -1) { return $langs->trans("ServiceStatusRunning"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 0) { return $langs->trans("ServiceStatusNotLateShort"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 1) { return $langs->trans("ServiceStatusLateShort"); }
+ elseif ($statut == self::STATUS_CLOSED) { return $langs->trans("ServiceStatusClosed"); }
}
- if ($mode == 2)
+ elseif ($mode == 2)
{
if ($statut == self::STATUS_INITIAL) { return img_picto($langs->trans('ServiceStatusInitial'),'statut0').' '.$langs->trans("ServiceStatusInitial"); }
- if ($statut == self::STATUS_OPEN && $expired == -1) { return img_picto($langs->trans('ServiceStatusRunning'),'statut4').' '.$langs->trans("ServiceStatusRunning"); }
- if ($statut == self::STATUS_OPEN && $expired == 0) { return img_picto($langs->trans('ServiceStatusNotLate'),'statut4').' '.$langs->trans("ServiceStatusNotLateShort"); }
- if ($statut == self::STATUS_OPEN && $expired == 1) { return img_picto($langs->trans('ServiceStatusLate'),'statut3').' '.$langs->trans("ServiceStatusLateShort"); }
- if ($statut == self::STATUS_CLOSED) { return img_picto($langs->trans('ServiceStatusClosed'),'statut6') .' '.$langs->trans("ServiceStatusClosed"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == -1) { return img_picto($langs->trans('ServiceStatusRunning'),'statut4').' '.$langs->trans("ServiceStatusRunning"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 0) { return img_picto($langs->trans('ServiceStatusNotLate'),'statut4').' '.$langs->trans("ServiceStatusNotLateShort"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 1) { return img_picto($langs->trans('ServiceStatusLate'),'statut3').' '.$langs->trans("ServiceStatusLateShort"); }
+ elseif ($statut == self::STATUS_CLOSED) { return img_picto($langs->trans('ServiceStatusClosed'),'statut6') .' '.$langs->trans("ServiceStatusClosed"); }
}
- if ($mode == 3)
+ elseif ($mode == 3)
{
if ($statut == self::STATUS_INITIAL) { return img_picto($langs->trans('ServiceStatusInitial'),'statut0',$moreatt); }
- if ($statut == self::STATUS_OPEN && $expired == -1) { return img_picto($langs->trans('ServiceStatusRunning'),'statut4',$moreatt); }
- if ($statut == self::STATUS_OPEN && $expired == 0) { return img_picto($langs->trans('ServiceStatusNotLate'),'statut4',$moreatt); }
- if ($statut == self::STATUS_OPEN && $expired == 1) { return img_picto($langs->trans('ServiceStatusLate'),'statut3',$moreatt); }
- if ($statut == self::STATUS_CLOSED) { return img_picto($langs->trans('ServiceStatusClosed'),'statut6',$moreatt); }
+ elseif ($statut == self::STATUS_OPEN && $expired == -1) { return img_picto($langs->trans('ServiceStatusRunning'),'statut4',$moreatt); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 0) { return img_picto($langs->trans('ServiceStatusNotLate'),'statut4',$moreatt); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 1) { return img_picto($langs->trans('ServiceStatusLate'),'statut3',$moreatt); }
+ elseif ($statut == self::STATUS_CLOSED) { return img_picto($langs->trans('ServiceStatusClosed'),'statut6',$moreatt); }
}
- if ($mode == 4)
+ elseif ($mode == 4)
{
if ($statut == self::STATUS_INITIAL) { return img_picto($langs->trans('ServiceStatusInitial'),'statut0').' '.$langs->trans("ServiceStatusInitial"); }
- if ($statut == self::STATUS_OPEN && $expired == -1) { return img_picto($langs->trans('ServiceStatusRunning'),'statut4').' '.$langs->trans("ServiceStatusRunning"); }
- if ($statut == self::STATUS_OPEN && $expired == 0) { return img_picto($langs->trans('ServiceStatusNotLate'),'statut4').' '.$langs->trans("ServiceStatusNotLate"); }
- if ($statut == self::STATUS_OPEN && $expired == 1) { return img_picto($langs->trans('ServiceStatusLate'),'statut3').' '.$langs->trans("ServiceStatusLate"); }
- if ($statut == self::STATUS_CLOSED) { return img_picto($langs->trans('ServiceStatusClosed'),'statut6') .' '.$langs->trans("ServiceStatusClosed"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == -1) { return img_picto($langs->trans('ServiceStatusRunning'),'statut4').' '.$langs->trans("ServiceStatusRunning"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 0) { return img_picto($langs->trans('ServiceStatusNotLate'),'statut4').' '.$langs->trans("ServiceStatusNotLate"); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 1) { return img_picto($langs->trans('ServiceStatusLate'),'statut3').' '.$langs->trans("ServiceStatusLate"); }
+ elseif ($statut == self::STATUS_CLOSED) { return img_picto($langs->trans('ServiceStatusClosed'),'statut6') .' '.$langs->trans("ServiceStatusClosed"); }
}
- if ($mode == 5)
+ elseif ($mode == 5)
{
if ($statut == self::STATUS_INITIAL) { return $langs->trans("ServiceStatusInitial").' '.img_picto($langs->trans('ServiceStatusInitial'),'statut0'); }
- if ($statut == self::STATUS_OPEN && $expired == -1) { return $langs->trans("ServiceStatusRunning").' '.img_picto($langs->trans('ServiceStatusRunning'),'statut4'); }
- if ($statut == self::STATUS_OPEN && $expired == 0) { return $langs->trans("ServiceStatusNotLateShort").' '.img_picto($langs->trans('ServiceStatusNotLateShort'),'statut4'); }
- if ($statut == self::STATUS_OPEN && $expired == 1) { return $langs->trans("ServiceStatusLateShort").' '.img_picto($langs->trans('ServiceStatusLate'),'statut3'); }
- if ($statut == self::STATUS_CLOSED) { return $langs->trans("ServiceStatusClosed").' '.img_picto($langs->trans('ServiceStatusClosed'),'statut6'); }
+ elseif ($statut == self::STATUS_OPEN && $expired == -1) { return $langs->trans("ServiceStatusRunning").' '.img_picto($langs->trans('ServiceStatusRunning'),'statut4'); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 0) { return $langs->trans("ServiceStatusNotLateShort").' '.img_picto($langs->trans('ServiceStatusNotLateShort'),'statut4'); }
+ elseif ($statut == self::STATUS_OPEN && $expired == 1) { return $langs->trans("ServiceStatusLateShort").' '.img_picto($langs->trans('ServiceStatusLate'),'statut3'); }
+ elseif ($statut == self::STATUS_CLOSED) { return $langs->trans("ServiceStatusClosed").' '.img_picto($langs->trans('ServiceStatusClosed'),'statut6'); }
}
}
@@ -3020,15 +3020,14 @@ class ContratLigne extends CommonObjectLine
}
}
- if (! $error)
- {
- if (! $notrigger)
- {
- // Call trigger
- $result=$this->call_trigger('LINECONTRACT_UPDATE', $user);
- if ($result < 0) { $error++; $this->db->rollback(); }
- // End call triggers
- }
+ if (! $error && ! $notrigger) {
+ // Call trigger
+ $result=$this->call_trigger('LINECONTRACT_UPDATE', $user);
+ if ($result < 0) {
+ $error++;
+ $this->db->rollback();
+ }
+ // End call triggers
}
if (! $error)
diff --git a/htdocs/core/boxes/box_factures_imp.php b/htdocs/core/boxes/box_factures_imp.php
index 54d265bf6af..dd64a07b8d9 100644
--- a/htdocs/core/boxes/box_factures_imp.php
+++ b/htdocs/core/boxes/box_factures_imp.php
@@ -86,7 +86,7 @@ class box_factures_imp extends ModeleBoxes
if ($user->rights->facture->lire)
{
- $sql = "SELECT s.nom as name, s.rowid as socid,";
+ $sql = "SELECT s.nom as name, s.rowid as socid, s.email,";
$sql.= " s.code_client,";
$sql.= " s.logo,";
$sql.= " f.facnumber, f.date_lim_reglement as datelimite,";
@@ -134,9 +134,11 @@ class box_factures_imp extends ModeleBoxes
$facturestatic->total_ttc = $objp->total_ttc;
$facturestatic->statut = $objp->fk_statut;
$facturestatic->date_lim_reglement = $db->jdate($objp->datelimite);
+
$societestatic->id = $objp->socid;
$societestatic->name = $objp->name;
$societestatic->client = 1;
+ $societestatic->email = $objp->email;
$societestatic->code_client = $objp->code_client;
$societestatic->logo = $objp->logo;
diff --git a/htdocs/core/class/commoninvoice.class.php b/htdocs/core/class/commoninvoice.class.php
index e9be4b1f9da..9b1cb8776c3 100644
--- a/htdocs/core/class/commoninvoice.class.php
+++ b/htdocs/core/class/commoninvoice.class.php
@@ -431,11 +431,11 @@ abstract class CommonInvoice extends CommonObject
{
global $langs;
if ($this->type == CommonInvoice::TYPE_STANDARD) return $langs->trans("InvoiceStandard");
- if ($this->type == CommonInvoice::TYPE_REPLACEMENT) return $langs->trans("InvoiceReplacement");
- if ($this->type == CommonInvoice::TYPE_CREDIT_NOTE) return $langs->trans("InvoiceAvoir");
- if ($this->type == CommonInvoice::TYPE_DEPOSIT) return $langs->trans("InvoiceDeposit");
- if ($this->type == CommonInvoice::TYPE_PROFORMA) return $langs->trans("InvoiceProForma"); // Not used.
- if ($this->type == CommonInvoice::TYPE_SITUATION) return $langs->trans("InvoiceSituation");
+ elseif ($this->type == CommonInvoice::TYPE_REPLACEMENT) return $langs->trans("InvoiceReplacement");
+ elseif ($this->type == CommonInvoice::TYPE_CREDIT_NOTE) return $langs->trans("InvoiceAvoir");
+ elseif ($this->type == CommonInvoice::TYPE_DEPOSIT) return $langs->trans("InvoiceDeposit");
+ elseif ($this->type == CommonInvoice::TYPE_PROFORMA) return $langs->trans("InvoiceProForma"); // Not used.
+ elseif ($this->type == CommonInvoice::TYPE_SITUATION) return $langs->trans("InvoiceSituation");
return $langs->trans("Unknown");
}
@@ -475,10 +475,10 @@ abstract class CommonInvoice extends CommonObject
if (! $paye)
{
if ($status == 0) return $langs->trans('Bill'.$prefix.'StatusDraft');
- if (($status == 3 || $status == 2) && $alreadypaid <= 0) return $langs->trans('Bill'.$prefix.'StatusClosedUnpaid');
- if (($status == 3 || $status == 2) && $alreadypaid > 0) return $langs->trans('Bill'.$prefix.'StatusClosedPaidPartially');
- if ($alreadypaid <= 0) return $langs->trans('Bill'.$prefix.'StatusNotPaid');
- return $langs->trans('Bill'.$prefix.'StatusStarted');
+ elseif (($status == 3 || $status == 2) && $alreadypaid <= 0) return $langs->trans('Bill'.$prefix.'StatusClosedUnpaid');
+ elseif (($status == 3 || $status == 2) && $alreadypaid > 0) return $langs->trans('Bill'.$prefix.'StatusClosedPaidPartially');
+ elseif ($alreadypaid <= 0) return $langs->trans('Bill'.$prefix.'StatusNotPaid');
+ else return $langs->trans('Bill'.$prefix.'StatusStarted');
}
else
{
@@ -493,10 +493,10 @@ abstract class CommonInvoice extends CommonObject
if (! $paye)
{
if ($status == 0) return $langs->trans('Bill'.$prefix.'StatusDraft');
- if (($status == 3 || $status == 2) && $alreadypaid <= 0) return $langs->trans('Bill'.$prefix.'StatusCanceled');
- if (($status == 3 || $status == 2) && $alreadypaid > 0) return $langs->trans('Bill'.$prefix.'StatusClosedPaidPartially');
- if ($alreadypaid <= 0) return $langs->trans('Bill'.$prefix.'StatusNotPaid');
- return $langs->trans('Bill'.$prefix.'StatusStarted');
+ elseif (($status == 3 || $status == 2) && $alreadypaid <= 0) return $langs->trans('Bill'.$prefix.'StatusCanceled');
+ elseif (($status == 3 || $status == 2) && $alreadypaid > 0) return $langs->trans('Bill'.$prefix.'StatusClosedPaidPartially');
+ elseif ($alreadypaid <= 0) return $langs->trans('Bill'.$prefix.'StatusNotPaid');
+ else return $langs->trans('Bill'.$prefix.'StatusStarted');
}
else
{
@@ -511,10 +511,10 @@ abstract class CommonInvoice extends CommonObject
if (! $paye)
{
if ($status == 0) return img_picto($langs->trans('BillStatusDraft'),'statut0').' '.$langs->trans('Bill'.$prefix.'StatusDraft');
- if (($status == 3 || $status == 2) && $alreadypaid <= 0) return img_picto($langs->trans('StatusCanceled'),'statut5').' '.$langs->trans('Bill'.$prefix.'StatusCanceled');
- if (($status == 3 || $status == 2) && $alreadypaid > 0) return img_picto($langs->trans('BillStatusClosedPaidPartially'),'statut9').' '.$langs->trans('Bill'.$prefix.'StatusClosedPaidPartially');
- if ($alreadypaid <= 0) return img_picto($langs->trans('BillStatusNotPaid'),'statut1').' '.$langs->trans('Bill'.$prefix.'StatusNotPaid');
- return img_picto($langs->trans('BillStatusStarted'),'statut3').' '.$langs->trans('Bill'.$prefix.'StatusStarted');
+ elseif (($status == 3 || $status == 2) && $alreadypaid <= 0) return img_picto($langs->trans('StatusCanceled'),'statut5').' '.$langs->trans('Bill'.$prefix.'StatusCanceled');
+ elseif (($status == 3 || $status == 2) && $alreadypaid > 0) return img_picto($langs->trans('BillStatusClosedPaidPartially'),'statut9').' '.$langs->trans('Bill'.$prefix.'StatusClosedPaidPartially');
+ elseif ($alreadypaid <= 0) return img_picto($langs->trans('BillStatusNotPaid'),'statut1').' '.$langs->trans('Bill'.$prefix.'StatusNotPaid');
+ else return img_picto($langs->trans('BillStatusStarted'),'statut3').' '.$langs->trans('Bill'.$prefix.'StatusStarted');
}
else
{
@@ -529,10 +529,10 @@ abstract class CommonInvoice extends CommonObject
if (! $paye)
{
if ($status == 0) return img_picto($langs->trans('BillStatusDraft'),'statut0');
- if (($status == 3 || $status == 2) && $alreadypaid <= 0) return img_picto($langs->trans('BillStatusCanceled'),'statut5');
- if (($status == 3 || $status == 2) && $alreadypaid > 0) return img_picto($langs->trans('BillStatusClosedPaidPartially'),'statut9');
- if ($alreadypaid <= 0) return img_picto($langs->trans('BillStatusNotPaid'),'statut1');
- return img_picto($langs->trans('BillStatusStarted'),'statut3');
+ elseif (($status == 3 || $status == 2) && $alreadypaid <= 0) return img_picto($langs->trans('BillStatusCanceled'),'statut5');
+ elseif (($status == 3 || $status == 2) && $alreadypaid > 0) return img_picto($langs->trans('BillStatusClosedPaidPartially'),'statut9');
+ elseif ($alreadypaid <= 0) return img_picto($langs->trans('BillStatusNotPaid'),'statut1');
+ else return img_picto($langs->trans('BillStatusStarted'),'statut3');
}
else
{
@@ -547,10 +547,10 @@ abstract class CommonInvoice extends CommonObject
if (! $paye)
{
if ($status == 0) return img_picto($langs->trans('BillStatusDraft'),'statut0').' '.$langs->trans('BillStatusDraft');
- if (($status == 3 || $status == 2) && $alreadypaid <= 0) return img_picto($langs->trans('BillStatusCanceled'),'statut5').' '.$langs->trans('Bill'.$prefix.'StatusCanceled');
- if (($status == 3 || $status == 2) && $alreadypaid > 0) return img_picto($langs->trans('BillStatusClosedPaidPartially'),'statut9').' '.$langs->trans('Bill'.$prefix.'StatusClosedPaidPartially');
- if ($alreadypaid <= 0) return img_picto($langs->trans('BillStatusNotPaid'),'statut1').' '.$langs->trans('BillStatusNotPaid');
- return img_picto($langs->trans('BillStatusStarted'),'statut3').' '.$langs->trans('BillStatusStarted');
+ elseif (($status == 3 || $status == 2) && $alreadypaid <= 0) return img_picto($langs->trans('BillStatusCanceled'),'statut5').' '.$langs->trans('Bill'.$prefix.'StatusCanceled');
+ elseif (($status == 3 || $status == 2) && $alreadypaid > 0) return img_picto($langs->trans('BillStatusClosedPaidPartially'),'statut9').' '.$langs->trans('Bill'.$prefix.'StatusClosedPaidPartially');
+ elseif ($alreadypaid <= 0) return img_picto($langs->trans('BillStatusNotPaid'),'statut1').' '.$langs->trans('BillStatusNotPaid');
+ else return img_picto($langs->trans('BillStatusStarted'),'statut3').' '.$langs->trans('BillStatusStarted');
}
else
{
@@ -566,14 +566,14 @@ abstract class CommonInvoice extends CommonObject
if (! $paye)
{
if ($status == 0) return ''.$langs->trans('Bill'.$prefix.'StatusDraft').' '.img_picto($langs->trans('BillStatusDraft'),'statut0');
- if (($status == 3 || $status == 2) && $alreadypaid <= 0) return ''.$langs->trans('Bill'.$prefix.'StatusCanceled').' '.img_picto($langs->trans('BillStatusCanceled'),'statut5');
- if (($status == 3 || $status == 2) && $alreadypaid > 0) return ''.$langs->trans('Bill'.$prefix.'StatusClosedPaidPartially').' '.img_picto($langs->trans('BillStatusClosedPaidPartially'),'statut9');
- if ($alreadypaid <= 0)
+ elseif (($status == 3 || $status == 2) && $alreadypaid <= 0) return ''.$langs->trans('Bill'.$prefix.'StatusCanceled').' '.img_picto($langs->trans('BillStatusCanceled'),'statut5');
+ elseif (($status == 3 || $status == 2) && $alreadypaid > 0) return ''.$langs->trans('Bill'.$prefix.'StatusClosedPaidPartially').' '.img_picto($langs->trans('BillStatusClosedPaidPartially'),'statut9');
+ elseif ($alreadypaid <= 0)
{
if ($type == self::TYPE_CREDIT_NOTE) return ''.$langs->trans('Bill'.$prefix.'StatusNotRefunded').' '.img_picto($langs->trans('StatusNotRefunded'),'statut1');
return ''.$langs->trans('Bill'.$prefix.'StatusNotPaid').' '.img_picto($langs->trans('BillStatusNotPaid'),'statut1');
}
- return ''.$langs->trans('Bill'.$prefix.'StatusStarted').' '.img_picto($langs->trans('BillStatusStarted'),'statut3');
+ else return ''.$langs->trans('Bill'.$prefix.'StatusStarted').' '.img_picto($langs->trans('BillStatusStarted'),'statut3');
}
else
{
@@ -598,7 +598,9 @@ abstract class CommonInvoice extends CommonObject
if (! $cond_reglement) $cond_reglement=$this->cond_reglement_code;
if (! $cond_reglement) $cond_reglement=$this->cond_reglement_id;
- $cdr_nbjour=0; $cdr_type=0; $cdr_decalage=0;
+ $cdr_nbjour=0;
+ $cdr_type=0;
+ $cdr_decalage=0;
$sqltemp = 'SELECT c.type_cdr,c.nbjour,c.decalage';
$sqltemp.= ' FROM '.MAIN_DB_PREFIX.'c_payment_term as c';
diff --git a/htdocs/core/class/commonobject.class.php b/htdocs/core/class/commonobject.class.php
index 034644b7e0f..475fbf2b1f0 100644
--- a/htdocs/core/class/commonobject.class.php
+++ b/htdocs/core/class/commonobject.class.php
@@ -7324,7 +7324,7 @@ abstract class CommonObject
$comment = new Comment($this->db);
$result=$comment->fetchAllFor($this->element, $this->id);
if ($result<0) {
- $this->errors=array_merge($this->errors,$comment->errors);
+ $this->errors=array_merge($this->errors, $comment->errors);
return -1;
} else {
$this->comments = $comment->comments;
@@ -7341,4 +7341,20 @@ abstract class CommonObject
{
return count($this->comments);
}
+
+ /**
+ * Trim object parameters
+ * @param string[] $parameters array of parameters to trim
+ *
+ * @return void
+ */
+ public function trimParameters($parameters)
+ {
+ if (!is_array($parameters)) return;
+ foreach ($parameters as $parameter) {
+ if (isset($this->$parameter)) {
+ $this->$parameter = trim($this->$parameter);
+ }
+ }
+ }
}
diff --git a/htdocs/core/class/html.formother.class.php b/htdocs/core/class/html.formother.class.php
index f30e2aed325..f79e9eea53d 100644
--- a/htdocs/core/class/html.formother.class.php
+++ b/htdocs/core/class/html.formother.class.php
@@ -1149,8 +1149,8 @@ class FormOther
if ($nbboxactivated)
{
- $langs->load("boxes");
- $langs->load("projects");
+ // Load translation files required by the page
+ $langs->loadLangs(array("boxes","projects"));
$emptybox=new ModeleBoxes($db);
diff --git a/htdocs/core/class/html.formsms.class.php b/htdocs/core/class/html.formsms.class.php
index 1e8a35fe3a4..165a4069b87 100644
--- a/htdocs/core/class/html.formsms.class.php
+++ b/htdocs/core/class/html.formsms.class.php
@@ -101,9 +101,8 @@ class FormSms
if (! is_object($form)) $form=new Form($this->db);
- $langs->load("other");
- $langs->load("mails");
- $langs->load("sms");
+ // Load translation files required by the page
+ $langs->loadLangs(array('other', 'mails', 'sms'));
$soc=new Societe($this->db);
if (!empty($this->withtosocid) && $this->withtosocid > 0)
diff --git a/htdocs/core/datepicker.php b/htdocs/core/datepicker.php
index a53f26f52a1..43957d6bd06 100644
--- a/htdocs/core/datepicker.php
+++ b/htdocs/core/datepicker.php
@@ -66,18 +66,19 @@ else
}
// Define tradMonths javascript array (we define this in datapicker AND in parent page to avoid errors with IE8)
-$tradTemp=array($langs->trans("January"),
-$langs->trans("February"),
-$langs->trans("March"),
-$langs->trans("April"),
-$langs->trans("May"),
-$langs->trans("June"),
-$langs->trans("July"),
-$langs->trans("August"),
-$langs->trans("September"),
-$langs->trans("October"),
-$langs->trans("November"),
-$langs->trans("December")
+$tradTemp=array(
+ $langs->trans("January"),
+ $langs->trans("February"),
+ $langs->trans("March"),
+ $langs->trans("April"),
+ $langs->trans("May"),
+ $langs->trans("June"),
+ $langs->trans("July"),
+ $langs->trans("August"),
+ $langs->trans("September"),
+ $langs->trans("October"),
+ $langs->trans("November"),
+ $langs->trans("December")
);
print '
diff --git a/htdocs/accountancy/admin/account.php b/htdocs/accountancy/admin/account.php
index ca47dbc7b96..087f9957f16 100644
--- a/htdocs/accountancy/admin/account.php
+++ b/htdocs/accountancy/admin/account.php
@@ -63,9 +63,9 @@ if (! $sortorder) $sortorder = "ASC";
$arrayfields=array(
'aa.account_number'=>array('label'=>$langs->trans("AccountNumber"), 'checked'=>1),
'aa.label'=>array('label'=>$langs->trans("Label"), 'checked'=>1),
- 'aa.account_parent'=>array('label'=>$langs->trans("Accountparent"), 'checked'=>0),
+ 'aa.account_parent'=>array('label'=>$langs->trans("Accountparent"), 'checked'=>1),
'aa.pcg_type'=>array('label'=>$langs->trans("Pcgtype"), 'checked'=>1, 'help'=>'PcgtypeDesc'),
- 'aa.pcg_subtype'=>array('label'=>$langs->trans("Pcgsubtype"), 'checked'=>1, 'help'=>'PcgtypeDesc'),
+ 'aa.pcg_subtype'=>array('label'=>$langs->trans("Pcgsubtype"), 'checked'=>0, 'help'=>'PcgtypeDesc'),
'aa.active'=>array('label'=>$langs->trans("Activated"), 'checked'=>1)
);
@@ -122,16 +122,34 @@ if (empty($reshook))
{
$sqlfile = DOL_DOCUMENT_ROOT.'/install/mysql/data/llx_accounting_account_'.strtolower($country_code).'.sql';
- // FIXME Get the ADD rowid and pass it + num of comapny * 100 000 000 to run_sql as a new parameter to say to update sql on the fly to add offset to rowid and account_parent value.
+ $offsetforchartofaccount = 0;
+ // Get the comment line '-- ADD CCCNNNNN to rowid...' to find CCCNNNNN (CCC is country num, NNNNN is id of accounting account)
+ // and pass CCCNNNNN + (num of company * 100 000 000) as offset to the run_sql as a new parameter to say to update sql on the fly to add offset to rowid and account_parent value.
+ // This is to be sure there is no conflict for each chart of account, whatever is country, whatever is company when multicompany is used.
+ $tmp = file_get_contents($sqlfile);
+ if (preg_match('/-- ADD (\d+) to rowid/ims', $tmp, $reg))
+ {
+ $offsetforchartofaccount += $reg[1];
+ }
+ $offsetforchartofaccount+=($conf->entity * 100000000);
- $result = run_sql($sqlfile, 1, 0, 1);
+ $result = run_sql($sqlfile, 1, $conf->entity, 1, '', 'default', 32768, 0, $offsetforchartofaccount);
+
+ if ($result > 0)
+ {
+ setEventMessages($langs->trans("ChartLoaded"), null);
+ }
+ else
+ {
+ setEventMessages($langs->trans("ErrorDuringChartLoad"), null, 'warnings');
+ }
}
if (! dolibarr_set_const($db, 'CHARTOFACCOUNTS', $chartofaccounts, 'chaine', 0, '', $conf->entity)) {
$error++;
}
} else {
- $error ++;
+ $error++;
}
}